# Glycowork



![CI](https://github.com/BojarLab/glycowork/workflows/CI/badge.svg)


<img src="glycowork_badge_wo_bg.jpg" width="200" style="max-width: 200px">

Glycans are a fundamental biological sequence, similar to DNA, RNA, or proteins. Glycans are complex carbohydrates that can form branched structures comprising monosaccharides and linkages as constituents. Despite being conspicuously absent from most research, glycans are ubiquitous in biology. They decorate most proteins and lipids and direct the stability and functions of biomolecules, cells, and organisms. This also makes glycans relevant to every human disease.

The analysis of glycans is made difficult by their nonlinearity and their astounding diversity, given the large number of monosaccharides and types of linkages. `Glycowork` is a Python package designed to process and analyze glycan sequences, with a special emphasis on glycan-focused data science and machine learning. Next to various functions to work with glycans, `Glycowork` also contains glycan data that can be used for glycan alignments, model pre-training, motif comparisons, etc.

The inspiration for `glycowork` can be found in [Bojar et al., 2020](https://doi.org/10.1016/j.chom.2020.10.004) and [Burkholz et al., 2021](https://www.biorxiv.org/content/10.1101/2021.03.01.433491v1). There, you can also find examples of possible use cases for the functions in `glycowork`.

The full documentation for `glycowork` can be found here: https://bojarlab.github.io/glycowork/

## Install

via pip: <br>
`pip install glycowork` <br>
`import glycowork`

alternative: <br>
`pip install git+https://github.com/BojarLab/glycowork.git` <br>
`import glycowork`

## How to use

`Glycowork` currently contains four main modules:
 - **`alignment`**
     - can be used to find similar glycan sequences by alignment according to a glycan-specific substitution matrix
 - **`glycan_data`**
     - stores several glycan datasets and contains helper functions
 - **`ml`**
     - here are all the functions for training and using machine learning models, including train-test-split, getting glycan representations, etc.
 - **`motif`**
     - contains functions for processing glycan sequences, identifying motifs and features, and analyzing them
     
Below are some examples of what you can do with `glycowork`, be sure to check out the other `examples` in the full documentation for everything that's there.

```python
#using graphs, you can easily check whether two glycans are the same - even if they use different bracket notations!
from glycowork.motif.graph import compare_glycans
print(compare_glycans('Man(a1-3)[Man(a1-6)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc',
                     'Man(a1-6)[Man(a1-3)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc'))
print(compare_glycans('Man(a1-3)[Man(a1-6)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc',
                     'Man(a1-6)[Man(a1-3)]Man(b1-4)GlcNAc(b1-4)GlcNAc'))
```

    True
    False
    

```python
#querying some of the stored databases
from glycowork.motif.query import get_insight
get_insight('Man(a1-3)[Man(a1-6)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc')
```

    Let's get rolling! Give us a few moments to crunch some numbers.
    
    This glycan occurs in the following species: ['Antheraea_pernyi', 'Apis_mellifera', 'Autographa_californica_nucleopolyhedrovirus', 'AvianInfluenzaA_Virus', 'Bombyx_mori', 'Bos_taurus', 'Caenorhabditis_elegans', 'Drosophila_melanogaster', 'Homo_sapiens', 'HumanImmunoDeficiency_Virus', 'Mamestra_brassicae', 'Megathura_crenulata', 'Mus_musculus', 'Rattus_norvegicus', 'Spodoptera_frugiperda', 'Sus_scrofa', 'Trichinella_spiralis']
    
    Puh, that's quite a lot! Here are the phyla of those species: ['Arthropoda', 'Chordata', 'Mollusca', 'Negarnaviricota', 'Nematoda', 'Virus']
    
    This glycan contains the following motifs: ['Chitobiose', 'Trimannosylcore', 'core_fucose']
    
    That's all we can do for you at this point!
    

```python
#get motifs, graph features, and sequence features of a set of glycan sequences to train models or analyze glycan properties
glycans = ['Man(a1-3)[Man(a1-6)][Xyl(b1-2)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-3)]GlcNAc',
           'Man(a1-2)Man(a1-2)Man(a1-3)[Man(a1-3)Man(a1-6)]Man(b1-4)GlcNAc(b1-4)GlcNAc',
           'GalNAc(a1-4)GlcNAcA(a1-4)[GlcN(b1-7)]Kdo(a2-5)[Kdo(a2-4)]Kdo(a2-6)GlcOPN(b1-6)GlcOPN']
from glycowork.motif.annotate import annotate_dataset
out = annotate_dataset(glycans, feature_set = ['known', 'graph', 'exhaustive']).head()
```




<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th></th>
      <th>LewisX</th>
      <th>LewisY</th>
      <th>SialylLewisX</th>
      <th>SulfoSialylLewisX</th>
      <th>LewisA</th>
      <th>LewisB</th>
      <th>SialylLewisA</th>
      <th>SulfoLewisA</th>
      <th>H_type2</th>
      <th>H_type1</th>
      <th>A_antigen</th>
      <th>B_antigen</th>
      <th>Galili_antigen</th>
      <th>GloboH</th>
      <th>Gb5</th>
      <th>Gb4</th>
      <th>Gb3</th>
      <th>3SGb3</th>
      <th>8DSGb3</th>
      <th>3SGb4</th>
      <th>8DSGb4</th>
      <th>6DSGb4</th>
      <th>3SGb5</th>
      <th>8DSGb5</th>
      <th>6DSGb5</th>
      <th>6DSGb5_2</th>
      <th>6SGb3</th>
      <th>8DSGb3_2</th>
      <th>6SGb4</th>
      <th>8DSGb4_2</th>
      <th>6SGb5</th>
      <th>8DSGb5_2</th>
      <th>66DSGb5</th>
      <th>Forssman_antigen</th>
      <th>iGb3</th>
      <th>I_antigen</th>
      <th>i_antigen</th>
      <th>PI_antigen</th>
      <th>Chitobiose</th>
      <th>Trimannosylcore</th>
      <th>Internal_LacNAc_type1</th>
      <th>Terminal_LacNAc_type1</th>
      <th>Internal_LacNAc_type2</th>
      <th>Terminal_LacNAc_type2</th>
      <th>Internal_LacdiNAc_type1</th>
      <th>Terminal_LacdiNAc_type1</th>
      <th>Internal_LacdiNAc_type2</th>
      <th>Terminal_LacdiNAc_type2</th>
      <th>bisectingGlcNAc</th>
      <th>VIM</th>
      <th>PolyLacNAc</th>
      <th>Ganglio_Series</th>
      <th>Lacto_Series(LewisC)</th>
      <th>NeoLacto_Series</th>
      <th>betaGlucan</th>
      <th>KeratanSulfate</th>
      <th>Hyluronan</th>
      <th>Mollu_series</th>
      <th>Arthro_series</th>
      <th>Cellulose_like</th>
      <th>Chondroitin_4S</th>
      <th>GPI_anchor</th>
      <th>Isoglobo_series</th>
      <th>LewisD</th>
      <th>Globo_series</th>
      <th>SDA</th>
      <th>Muco_series</th>
      <th>Heparin</th>
      <th>Peptidoglycan</th>
      <th>Dermatansulfate</th>
      <th>CAD</th>
      <th>Lactosylceramide</th>
      <th>Lactotriaosylceramide</th>
      <th>LexLex</th>
      <th>GM3</th>
      <th>H_type3</th>
      <th>GM2</th>
      <th>GM1</th>
      <th>cisGM1</th>
      <th>VIM2</th>
      <th>GD3</th>
      <th>GD1a</th>
      <th>GD2</th>
      <th>GD1b</th>
      <th>SDLex</th>
      <th>Nglycolyl_GM2</th>
      <th>Fuc_LN3</th>
      <th>GT1b</th>
      <th>GD1</th>
      <th>GD1a_2</th>
      <th>LcGg4</th>
      <th>GT3</th>
      <th>Disialyl_T_antigen</th>
      <th>GT1a</th>
      <th>GT2</th>
      <th>GT1c</th>
      <th>2Fuc_GM1</th>
      <th>GQ1c</th>
      <th>O_linked_mannose</th>
      <th>GT1aa</th>
      <th>GQ1b</th>
      <th>HNK1</th>
      <th>GQ1ba</th>
      <th>O_mannose_Lex</th>
      <th>2Fuc_GD1b</th>
      <th>Sialopentaosylceramide</th>
      <th>Sulfogangliotetraosylceramide</th>
      <th>B-GM1</th>
      <th>GQ1aa</th>
      <th>bisSulfo-Lewis x</th>
      <th>para-Forssman</th>
      <th>core_fucose</th>
      <th>core_fucose(a1-3)</th>
      <th>GP1c</th>
      <th>B-GD1b</th>
      <th>GP1ca</th>
      <th>Isoglobotetraosylceramide</th>
      <th>polySia</th>
      <th>high_mannose</th>
      <th>Gala_series</th>
      <th>LPS_core</th>
      <th>Nglycan_complex</th>
      <th>Nglycan_complex2</th>
      <th>Oglycan_core2</th>
      <th>Oglycan_core3</th>
      <th>Oglycan_core4</th>
      <th>Oglycan_core5</th>
      <th>Oglycan_core6</th>
      <th>Oglycan_core7</th>
      <th>Xylogalacturonan</th>
      <th>Sialosylparagloboside</th>
      <th>LDNF</th>
      <th>OFuc</th>
      <th>Arabinogalactan_type2</th>
      <th>EGF_repeat</th>
      <th>Nglycan_hybrid</th>
      <th>Arabinan</th>
      <th>Xyloglucan</th>
      <th>Acharan_Sulfate</th>
      <th>M3FX</th>
      <th>M3X</th>
      <th>1-6betaGalactan</th>
      <th>Arabinogalactan_type1</th>
      <th>Galactomannan</th>
      <th>Tetraantennary_Nglycan</th>
      <th>Mucin_elongated_core2</th>
      <th>Fucoidan</th>
      <th>Alginate</th>
      <th>FG</th>
      <th>XX</th>
      <th>diameter</th>
      <th>branching</th>
      <th>nbrLeaves</th>
      <th>avgDeg</th>
      <th>varDeg</th>
      <th>maxDeg</th>
      <th>nbrDeg4</th>
      <th>max_deg_leaves</th>
      <th>mean_deg_leaves</th>
      <th>deg_assort</th>
      <th>betweeness</th>
      <th>betwVar</th>
      <th>betwMax</th>
      <th>eigenMax</th>
      <th>eigenMin</th>
      <th>eigenAvg</th>
      <th>eigenVar</th>
      <th>closeMax</th>
      <th>closeMin</th>
      <th>closeAvg</th>
      <th>closeVar</th>
      <th>flowMax</th>
      <th>flowAvg</th>
      <th>flowVar</th>
      <th>flow_edgeMax</th>
      <th>flow_edgeMin</th>
      <th>flow_edgeAvg</th>
      <th>flow_edgeVar</th>
      <th>loadMax</th>
      <th>loadAvg</th>
      <th>loadVar</th>
      <th>harmMax</th>
      <th>harmMin</th>
      <th>harmAvg</th>
      <th>harmVar</th>
      <th>secorderMax</th>
      <th>secorderMin</th>
      <th>secorderAvg</th>
      <th>secorderVar</th>
      <th>size_corona</th>
      <th>size_core</th>
      <th>nbr_node_types</th>
      <th>egap</th>
      <th>entropyStation</th>
      <th>N</th>
      <th>dens</th>
      <th></th>
      <th>1,4-Anhydro-Gal</th>
      <th>1,4-Anhydro-Kdo</th>
      <th>1-1</th>
      <th>1-2</th>
      <th>1-3</th>
      <th>1-4</th>
      <th>1-5</th>
      <th>1-6</th>
      <th>1dAlt-ol</th>
      <th>1dEry-ol</th>
      <th>2,3-Anhydro-All</th>
      <th>2,3-Anhydro-Man</th>
      <th>2,3-Anhydro-Rib</th>
      <th>2,5-Anhydro-D-Alt</th>
      <th>2,5-Anhydro-D-AltOS</th>
      <th>2,5-Anhydro-L-Man</th>
      <th>2,5-Anhydro-Man</th>
      <th>2,5-Anhydro-Man-ol</th>
      <th>2,5-Anhydro-ManOS</th>
      <th>2,5-Anhydro-Tal-ol</th>
      <th>2,5-Anhydro-TalOP</th>
      <th>2,7-Anhydro-Kdo</th>
      <th>2,7-Anhydro-Kdof</th>
      <th>2-4</th>
      <th>2-5</th>
      <th>2-6</th>
      <th>3</th>
      <th>3,6-Anhydro-Fruf</th>
      <th>3,6-Anhydro-Gal</th>
      <th>3,6-Anhydro-GalOS</th>
      <th>3,6-Anhydro-Glc</th>
      <th>3,6-Anhydro-L-Gal</th>
      <th>3,6-Anhydro-L-GalOMe</th>
      <th>3-3</th>
      <th>3-5</th>
      <th>3-6</th>
      <th>3dLyxHepUlosaric</th>
      <th>4</th>
      <th>4,7-Anhydro-KdoOPEtn</th>
      <th>4,8-Anhydro-DDGlcOct</th>
      <th>4,8-Anhydro-Kdo</th>
      <th>4,8-Anhydro-LDGlcOct</th>
      <th>4-5</th>
      <th>4dAraHex</th>
      <th>4dEry-ol</th>
      <th>4dGal</th>
      <th>4dNeu5Ac</th>
      <th>4eLeg5Ac7Ac</th>
      <th>5-2</th>
      <th>5-3</th>
      <th>5-5</th>
      <th>5-6</th>
      <th>6dAlt</th>
      <th>6dAltNAc</th>
      <th>6dAltOAc</th>
      <th>6dAltf</th>
      <th>6dAltfOAc</th>
      <th>6dGal</th>
      <th>6dGul</th>
      <th>6dManHep</th>
      <th>6dTal</th>
      <th>6dTalNAc</th>
      <th>6dTalNAcOAc</th>
      <th>6dTalOAc</th>
      <th>6dTalOAcOAc</th>
      <th>6dTalOAcOMe</th>
      <th>6dTalOMe</th>
      <th>6dTalOMe-ol</th>
      <th>6dTalf</th>
      <th>7dNeu5Ac</th>
      <th>8dNeu5Ac</th>
      <th>8eAciNAcNAc</th>
      <th>8eLeg</th>
      <th>8eLeg5Ac7Ac</th>
      <th>8eLeg5Ac7AcGro</th>
      <th>8eLegNAc</th>
      <th>8eLegNAcNBut</th>
      <th>9dNeu5Ac</th>
      <th>Abe</th>
      <th>AbeOAc</th>
      <th>AcefA</th>
      <th>AciNAcNAc</th>
      <th>Aco</th>
      <th>AcoNAc</th>
      <th>AllN</th>
      <th>AllOAc</th>
      <th>AllOMe</th>
      <th>Alt</th>
      <th>AltA</th>
      <th>AltAN</th>
      <th>AltNAcA</th>
      <th>AltOMeA</th>
      <th>Altf</th>
      <th>AltfOAc</th>
      <th>Ami</th>
      <th>ApiOAc</th>
      <th>ApiOMe-ol</th>
      <th>Apif</th>
      <th>Ara</th>
      <th>Ara-ol</th>
      <th>AraHepUloNAc-onic</th>
      <th>AraHepUloNAcN-onic</th>
      <th>AraHepUloNGc-onic</th>
      <th>AraHexA</th>
      <th>AraN</th>
      <th>AraNMeOMe</th>
      <th>AraOAc</th>
      <th>AraOAcOP-ol</th>
      <th>AraOMe</th>
      <th>AraOPN</th>
      <th>Araf</th>
      <th>ArafGro</th>
      <th>ArafOCoum</th>
      <th>ArafOFer</th>
      <th>ArafOMe</th>
      <th>ArafOS</th>
      <th>Asc</th>
      <th>Bac</th>
      <th>BacNAc</th>
      <th>BoiOMe</th>
      <th>Col</th>
      <th>D-2dAraHex</th>
      <th>D-2dAraHexA</th>
      <th>D-3dAraHepUlosonic</th>
      <th>D-3dLyxHepUlosaric</th>
      <th>D-3dThrHexUlosonic</th>
      <th>D-3dThrPen</th>
      <th>D-3dXylHexOMe</th>
      <th>D-4dAraHex</th>
      <th>D-4dEryHexOAcN4en</th>
      <th>D-4dLyxHex</th>
      <th>D-4dLyxHexOMe</th>
      <th>D-4dThrHexA4en</th>
      <th>D-4dThrHexAN4en</th>
      <th>D-4dThrHexOAcN4en</th>
      <th>D-4dXylHex</th>
      <th>D-6dAllOMe</th>
      <th>D-6dAlt</th>
      <th>D-6dAltHep</th>
      <th>D-6dAltHepOMe</th>
      <th>D-6dAltHepf</th>
      <th>D-6dAraHex</th>
      <th>D-6dAraHexN</th>
      <th>D-6dAraHexNAc</th>
      <th>D-6dAraHexOMe</th>
      <th>D-6dLyxHexOMe</th>
      <th>D-6dManHep</th>
      <th>D-6dManHepOAc</th>
      <th>D-6dManHepOP</th>
      <th>D-6dTal</th>
      <th>D-6dTalHep</th>
      <th>D-6dTalOAc</th>
      <th>D-6dTalOAcOMe</th>
      <th>D-6dTalOMe</th>
      <th>D-6dXylHex</th>
      <th>D-6dXylHexN4Ulo</th>
      <th>D-6dXylHexNAc4Ulo</th>
      <th>D-6dXylHexOMe</th>
      <th>D-7dLyxOctUlosonic</th>
      <th>D-9dThrAltNon-onic</th>
      <th>D-Alt</th>
      <th>D-Apif</th>
      <th>D-ApifOAc</th>
      <th>D-ApifOMe</th>
      <th>D-Ara</th>
      <th>D-Ara-ol</th>
      <th>D-AraHepUlo-onic</th>
      <th>D-AraHex</th>
      <th>D-AraHexUloOMe</th>
      <th>D-AraN</th>
      <th>D-AraOS</th>
      <th>D-Araf</th>
      <th>D-ArafN</th>
      <th>D-Fuc</th>
      <th>D-Fuc-ol</th>
      <th>D-FucN</th>
      <th>D-FucNAc</th>
      <th>D-FucNAc-ol</th>
      <th>D-FucNAcN</th>
      <th>D-FucNAcNMe</th>
      <th>D-FucNAcNMeN</th>
      <th>D-FucNAcOAc</th>
      <th>D-FucNAcOMe</th>
      <th>D-FucNAcOP</th>
      <th>D-FucNAcOPEtn</th>
      <th>D-FucNAlaAc</th>
      <th>D-FucNAsp</th>
      <th>D-FucNBut</th>
      <th>D-FucNButGro</th>
      <th>D-FucNFo</th>
      <th>D-FucNLac</th>
      <th>D-FucNMeN</th>
      <th>D-FucNN</th>
      <th>D-FucNThrAc</th>
      <th>D-FucOAc</th>
      <th>D-FucOAcN</th>
      <th>D-FucOAcNBut</th>
      <th>D-FucOAcNGroA</th>
      <th>D-FucOAcOBut</th>
      <th>D-FucOAcOMe</th>
      <th>D-FucOBut</th>
      <th>D-FucOEtn</th>
      <th>D-FucOMe</th>
      <th>D-FucOMeN</th>
      <th>D-FucOMeOCoum</th>
      <th>D-FucOMeOFer</th>
      <th>D-FucOMeOSin</th>
      <th>D-FucOS</th>
      <th>D-Fucf</th>
      <th>D-FucfNAc</th>
      <th>D-FucfOAc</th>
      <th>D-Ido</th>
      <th>D-IdoA</th>
      <th>D-IdoOSA</th>
      <th>D-Rha</th>
      <th>D-Rha-ol</th>
      <th>D-RhaCMe</th>
      <th>D-RhaGro</th>
      <th>D-RhaN</th>
      <th>D-RhaNAc</th>
      <th>D-RhaNAcOAc</th>
      <th>D-RhaNBut</th>
      <th>D-RhaNButOMe</th>
      <th>D-RhaNFo</th>
      <th>D-RhaOFoN</th>
      <th>D-RhaOMe</th>
      <th>D-RhaOMeN</th>
      <th>D-RhaOP</th>
      <th>D-RhaOS</th>
      <th>D-RibHex</th>
      <th>D-RibHexNAc</th>
      <th>D-Sor</th>
      <th>D-ThrHexA4en</th>
      <th>D-ThrHexAN4en</th>
      <th>D-ThrHexfNAc2en</th>
      <th>D-ThrPen</th>
      <th>D-Thre-ol</th>
      <th>DDAltHep</th>
      <th>DDAltHepOMe</th>
      <th>DDGalHep</th>
      <th>DDGalHepOMe</th>
      <th>DDGlcHep</th>
      <th>DDManHep</th>
      <th>DDManHepGroPA</th>
      <th>DDManHepOBut</th>
      <th>DDManHepOEtn</th>
      <th>DDManHepOMe</th>
      <th>DDManHepOP</th>
      <th>DDManHepOPEtn</th>
      <th>DDManNonUloNAcOFoN-onic</th>
      <th>DLAltNonUloNAc-onic</th>
      <th>DLGalNonUloNAc-onic</th>
      <th>DLGalNonUloNAcN</th>
      <th>DLGalNonUloNAcN-onic</th>
      <th>DLGlcHepOMe</th>
      <th>DLHepGlcOMe</th>
      <th>DLManHep</th>
      <th>DLManHepOPEtn</th>
      <th>Dha</th>
      <th>Dig</th>
      <th>DigCMe</th>
      <th>DigOAc</th>
      <th>DigOFo</th>
      <th>DigOMe</th>
      <th>Ery</th>
      <th>Ery-L-GlcNonUloNAcOAcOMeSH-onic</th>
      <th>Ery-ol</th>
      <th>Ery-onic</th>
      <th>EryHex</th>
      <th>EryHex2en</th>
      <th>EryHexA3en</th>
      <th>EryOMe-onic</th>
      <th>Fru</th>
      <th>Fruf</th>
      <th>FrufF</th>
      <th>FrufI</th>
      <th>FrufN</th>
      <th>FrufNAc</th>
      <th>FrufOAc</th>
      <th>FrufOAcOBzOCoum</th>
      <th>FrufOAcOFer</th>
      <th>FrufOBzOCin</th>
      <th>FrufOBzOCoum</th>
      <th>FrufOBzOFer</th>
      <th>FrufOFer</th>
      <th>FrufOLau</th>
      <th>Fuc</th>
      <th>Fuc-ol</th>
      <th>Fuc4S</th>
      <th>FucN</th>
      <th>FucNAc</th>
      <th>FucNAcA</th>
      <th>FucNAcGroP</th>
      <th>FucNAcN</th>
      <th>FucNAcNMe</th>
      <th>FucNAcOAc</th>
      <th>FucNAcOMe</th>
      <th>FucNAla</th>
      <th>FucNAm</th>
      <th>FucNBut</th>
      <th>FucNFo</th>
      <th>FucNProp</th>
      <th>FucNThrAc</th>
      <th>FucOAc</th>
      <th>FucOAcNAm</th>
      <th>FucOAcNBut</th>
      <th>FucOAcOMe</th>
      <th>FucOAcOSOMe</th>
      <th>FucOMe</th>
      <th>FucOMeOPam</th>
      <th>FucOMeOVac</th>
      <th>FucOP</th>
      <th>FucOPOMe</th>
      <th>FucOS</th>
      <th>FucOSOMe</th>
      <th>Fucf</th>
      <th>Gal</th>
      <th>Gal-ol</th>
      <th>Gal3S</th>
      <th>Gal6S</th>
      <th>Gal6Ulo</th>
      <th>GalA</th>
      <th>GalA-ol</th>
      <th>GalAAla</th>
      <th>GalAAlaLys</th>
      <th>GalAGroN</th>
      <th>GalALys</th>
      <th>GalAN</th>
      <th>GalANCys</th>
      <th>GalANCysAc</th>
      <th>GalANSerAc</th>
      <th>GalAOLac</th>
      <th>GalAOPyr</th>
      <th>GalASer</th>
      <th>GalAThr</th>
      <th>GalAThrAc</th>
      <th>GalCl</th>
      <th>GalF</th>
      <th>GalGro</th>
      <th>GalGroN</th>
      <th>GalGroP</th>
      <th>GalN</th>
      <th>GalNAc</th>
      <th>GalNAc-ol</th>
      <th>GalNAc-onic</th>
      <th>GalNAc4S</th>
      <th>GalNAcA</th>
      <th>GalNAcAAla</th>
      <th>GalNAcAN</th>
      <th>GalNAcASer</th>
      <th>GalNAcGro</th>
      <th>GalNAcGroP</th>
      <th>GalNAcGroPAN</th>
      <th>GalNAcN</th>
      <th>GalNAcOAc</th>
      <th>GalNAcOAcA</th>
      <th>GalNAcOAcAN</th>
      <th>GalNAcOAcGroP</th>
      <th>GalNAcOAcOMeA</th>
      <th>GalNAcOAcOP</th>
      <th>GalNAcOMe</th>
      <th>GalNAcOP</th>
      <th>GalNAcOPCho</th>
      <th>GalNAcOPEtn</th>
      <th>GalNAcOPyr</th>
      <th>GalNAcOS</th>
      <th>GalNAla</th>
      <th>GalNAmA</th>
      <th>GalNCysGly</th>
      <th>GalNFoA</th>
      <th>GalNFoAN</th>
      <th>GalNOPCho</th>
      <th>GalNSuc</th>
      <th>GalNonUloNAc-onic</th>
      <th>GalOAc</th>
      <th>GalOAcA</th>
      <th>GalOAcAGroN</th>
      <th>GalOAcAOLac</th>
      <th>GalOAcAThr</th>
      <th>GalOAcGroP</th>
      <th>GalOAcN</th>
      <th>GalOAcNAla</th>
      <th>GalOAcNAmA</th>
      <th>GalOAcNFoA</th>
      <th>GalOAcNFoAN</th>
      <th>GalOAcOFoA</th>
      <th>GalOAcOMe</th>
      <th>GalOAcOP</th>
      <th>GalOAcOPyr</th>
      <th>GalOFoAN</th>
      <th>GalOFoNAN</th>
      <th>GalOLac</th>
      <th>GalOLac-ol</th>
      <th>GalOMe</th>
      <th>GalOMeA</th>
      <th>GalOMeCl</th>
      <th>GalOMeF</th>
      <th>GalOMeNAla</th>
      <th>GalOP</th>
      <th>GalOPA</th>
      <th>GalOPAEtn</th>
      <th>GalOPAN</th>
      <th>GalOPCho</th>
      <th>GalOPEtn</th>
      <th>GalOPEtnA</th>
      <th>GalOPEtnN</th>
      <th>GalOPy</th>
      <th>GalOPyr</th>
      <th>GalOS</th>
      <th>GalOSA</th>
      <th>GalOSOEt</th>
      <th>GalOSOMeA</th>
      <th>GalOctUloNAc-onic</th>
      <th>Galf</th>
      <th>GalfGro</th>
      <th>GalfGroP</th>
      <th>GalfNAc</th>
      <th>GalfOAc</th>
      <th>GalfOAcGro</th>
      <th>GalfOAcGroP</th>
      <th>GalfOAcOLac</th>
      <th>GalfOLac</th>
      <th>GalfOMe</th>
      <th>GalfOP</th>
      <th>GalfOPCho</th>
      <th>GalfOPyr</th>
      <th>Gl</th>
      <th>Glc</th>
      <th>Glc-ol</th>
      <th>Glc6Ulo</th>
      <th>GlcA</th>
      <th>GlcA3S</th>
      <th>GlcAAla</th>
      <th>GlcAAlaLys</th>
      <th>GlcAGlu</th>
      <th>GlcAGly</th>
      <th>GlcAGro</th>
      <th>GlcAGroN</th>
      <th>GlcALys</th>
      <th>GlcAN</th>
      <th>GlcAOLac</th>
      <th>GlcAOPy</th>
      <th>GlcAOPyr</th>
      <th>GlcASer</th>
      <th>GlcAThr</th>
      <th>GlcAThrAc</th>
      <th>GlcCho</th>
      <th>GlcF</th>
      <th>GlcGro</th>
      <th>GlcGroA</th>
      <th>GlcGroP</th>
      <th>GlcGroPA</th>
      <th>GlcI</th>
      <th>GlcN</th>
      <th>GlcN-ol</th>
      <th>GlcN2S6S</th>
      <th>GlcNAc</th>
      <th>GlcNAc-ol</th>
      <th>GlcNAc6S</th>
      <th>GlcNAcA</th>
      <th>GlcNAcAAla</th>
      <th>GlcNAcAN</th>
      <th>GlcNAcANAla</th>
      <th>GlcNAcANAlaAc</th>
      <th>GlcNAcANAlaFo</th>
      <th>GlcNAcAla</th>
      <th>GlcNAcCl</th>
      <th>GlcNAcGlu</th>
      <th>GlcNAcGly</th>
      <th>GlcNAcGro</th>
      <th>GlcNAcGroP</th>
      <th>GlcNAcGroPA</th>
      <th>GlcNAcI</th>
      <th>GlcNAcN</th>
      <th>GlcNAcN-ol</th>
      <th>GlcNAcNAla</th>
      <th>GlcNAcNAlaFo</th>
      <th>GlcNAcNAmA</th>
      <th>GlcNAcNButA</th>
      <th>GlcNAcOAc</th>
      <th>GlcNAcOAcA</th>
      <th>GlcNAcOAcN</th>
      <th>GlcNAcOAcNAla</th>
      <th>GlcNAcOAcOCmOOle</th>
      <th>GlcNAcOAcOCmOPam</th>
      <th>GlcNAcOAcOCmOVac</th>
      <th>GlcNAcOAcOLac</th>
      <th>GlcNAcOAcOOle</th>
      <th>GlcNAcOAcOPam</th>
      <th>GlcNAcOAcOPyr</th>
      <th>GlcNAcOAcOS-ol</th>
      <th>GlcNAcOAcOVac</th>
      <th>GlcNAcOGc</th>
      <th>GlcNAcOLac</th>
      <th>GlcNAcOLacAla</th>
      <th>GlcNAcOLacGro</th>
      <th>GlcNAcOMe</th>
      <th>GlcNAcOMeA</th>
      <th>GlcNAcOP</th>
      <th>GlcNAcOPCho</th>
      <th>GlcNAcOPEtg</th>
      <th>GlcNAcOPEtn</th>
      <th>GlcNAcOPOAch</th>
      <th>GlcNAcOProp</th>
      <th>GlcNAcOPyr</th>
      <th>GlcNAcOS</th>
      <th>GlcNAcOS-ol</th>
      <th>GlcNAcOSA</th>
      <th>GlcNAm</th>
      <th>GlcNAmA</th>
      <th>GlcNBut</th>
      <th>GlcNButAN</th>
      <th>GlcNButOAc</th>
      <th>GlcNCmOCm</th>
      <th>GlcNCmOCmOOle</th>
      <th>GlcNCmOCmOVac</th>
      <th>GlcNCmOVac</th>
      <th>GlcNGc</th>
      <th>GlcNGly</th>
      <th>GlcNMe</th>
      <th>GlcNMeOCm</th>
      <th>GlcNMeOCmOPam</th>
      <th>GlcNMeOCmOSte</th>
      <th>GlcNMeOCmOVac</th>
      <th>GlcNMeOSte</th>
      <th>GlcNMeOVac</th>
      <th>GlcNN</th>
      <th>GlcNOAep</th>
      <th>GlcNOCmOAch</th>
      <th>GlcNOCmOVac</th>
      <th>GlcNOMar</th>
      <th>GlcNOMe</th>
      <th>GlcNOMyr</th>
      <th>GlcNOOle</th>
      <th>GlcNOPam</th>
      <th>GlcNOPyr</th>
      <th>GlcNOSte</th>
      <th>GlcNOVac</th>
      <th>GlcNS</th>
      <th>GlcNSOS</th>
      <th>GlcNSOSOMe</th>
      <th>GlcNSuc</th>
      <th>GlcOAc</th>
      <th>GlcOAcA</th>
      <th>GlcOAcGro</th>
      <th>GlcOAcGroA</th>
      <th>GlcOAcGroP</th>
      <th>GlcOAcN</th>
      <th>GlcOAcNBut</th>
      <th>GlcOAcNCmOOle</th>
      <th>GlcOAcNCmOPam</th>
      <th>GlcOAcNCmOVac</th>
      <th>GlcOAcNMeOCm</th>
      <th>GlcOAcNMeOCmOVac</th>
      <th>GlcOAcNMeOVac</th>
      <th>GlcOAcNOCmOVac</th>
      <th>GlcOAcNOOle</th>
      <th>GlcOAcNOPam</th>
      <th>GlcOAcNOVac</th>
      <th>GlcOAcOCoum</th>
      <th>GlcOAcOFer</th>
      <th>GlcOAcOOle</th>
      <th>GlcOAcOP</th>
      <th>GlcOAcOPam</th>
      <th>GlcOAcOS</th>
      <th>GlcOAcOSA</th>
      <th>GlcOAcOSte</th>
      <th>GlcOButA</th>
      <th>GlcOBz</th>
      <th>GlcOCoum</th>
      <th>GlcOEt</th>
      <th>GlcOEtn</th>
      <th>GlcOEtnA</th>
      <th>GlcOEtnN</th>
      <th>GlcOFer</th>
      <th>GlcOFoN</th>
      <th>GlcOGc</th>
      <th>GlcOLac</th>
      <th>GlcOMal</th>
      <th>GlcOMe</th>
      <th>GlcOMe-ol</th>
      <th>GlcOMeA</th>
      <th>GlcOMeAN</th>
      <th>GlcOMeN</th>
      <th>GlcOMeNOMyr</th>
      <th>GlcOMeOFoA</th>
      <th>GlcOMeOPyr</th>
      <th>GlcOOle</th>
      <th>GlcOP</th>
      <th>GlcOP-ol</th>
      <th>GlcOPA</th>
      <th>GlcOPCho</th>
      <th>GlcOPChoGro</th>
      <th>GlcOPEtn</th>
      <th>GlcOPEtnGro</th>
      <th>GlcOPEtnN</th>
      <th>GlcOPGroP</th>
      <th>GlcOPN</th>
      <th>GlcOPNOMyr</th>
      <th>GlcOPNOPam</th>
      <th>GlcOPOOle</th>
      <th>GlcOPPEtn</th>
      <th>GlcOPPEtnN</th>
      <th>GlcOPam</th>
      <th>GlcOPyr</th>
      <th>GlcOS</th>
      <th>GlcOSA</th>
      <th>GlcOSN</th>
      <th>GlcOSNMeOCm</th>
      <th>GlcOSOEt</th>
      <th>GlcOSOMe</th>
      <th>GlcOSOMeA</th>
      <th>GlcOSin</th>
      <th>GlcS</th>
      <th>GlcSH</th>
      <th>GlcThr</th>
      <th>Glcf</th>
      <th>Gro</th>
      <th>Gro-ol</th>
      <th>Gul</th>
      <th>GulAN</th>
      <th>GulNAcA</th>
      <th>GulNAcAN</th>
      <th>GulNAcNAmA</th>
      <th>GulNAcOAcA</th>
      <th>Hep</th>
      <th>HepOP</th>
      <th>HepOPEtn</th>
      <th>HepOPPEtn</th>
      <th>Hex</th>
      <th>HexA</th>
      <th>HexN</th>
      <th>HexNAc</th>
      <th>HexOMeOFo</th>
      <th>Hexf</th>
      <th>Ido</th>
      <th>IdoA</th>
      <th>IdoA2S</th>
      <th>IdoN</th>
      <th>IdoNAc</th>
      <th>IdoOAcA</th>
      <th>IdoOAcOSA</th>
      <th>IdoOMeA</th>
      <th>IdoOS</th>
      <th>IdoOSA</th>
      <th>IdoOSOEtA</th>
      <th>IdoOSOMeA</th>
      <th>Kdn</th>
      <th>KdnOAc</th>
      <th>KdnOMe</th>
      <th>KdnOPyr</th>
      <th>Kdo</th>
      <th>Kdo-ol</th>
      <th>KdoGroP</th>
      <th>KdoN</th>
      <th>KdoOAc</th>
      <th>KdoOAcOS</th>
      <th>KdoOMe</th>
      <th>KdoOP</th>
      <th>KdoOPEtn</th>
      <th>KdoOPN</th>
      <th>KdoOPOEtn</th>
      <th>KdoOPOPEtn</th>
      <th>KdoOPPEtn</th>
      <th>KdoOPPEtnN</th>
      <th>KdoOPyr</th>
      <th>KdoOS</th>
      <th>Kdof</th>
      <th>Ko</th>
      <th>KoOMe</th>
      <th>KoOPEtn</th>
      <th>L-4dEryHexAN4en</th>
      <th>L-4dThrHex4en</th>
      <th>L-4dThrHexA4en</th>
      <th>L-4dThrHexA4enAla</th>
      <th>L-4dThrHexAN4en</th>
      <th>L-4dThre-ol</th>
      <th>L-6dAraHex</th>
      <th>L-6dAraHexOMe</th>
      <th>L-6dGalHep</th>
      <th>L-6dGalHepOP</th>
      <th>L-6dGulHep</th>
      <th>L-6dGulHepOMe</th>
      <th>L-6dGulHepOP</th>
      <th>L-6dXylHexNAc4Ulo</th>
      <th>L-Aco</th>
      <th>L-AcoOMe</th>
      <th>L-AcoOMeOFo</th>
      <th>L-BoiOMe</th>
      <th>L-Cym</th>
      <th>L-CymOAc</th>
      <th>L-DigOMe</th>
      <th>L-Ery</th>
      <th>L-EryCMeOH</th>
      <th>L-EryHexA4en</th>
      <th>L-Fru</th>
      <th>L-Fruf</th>
      <th>L-Gal</th>
      <th>L-GalAN</th>
      <th>L-GalNAc</th>
      <th>L-GalNAc-onic</th>
      <th>L-GalNAcA</th>
      <th>L-GalNAcAN</th>
      <th>L-GalNAcOAcA</th>
      <th>L-GalNAmA</th>
      <th>L-GalOAcNAmA</th>
      <th>L-GalOS</th>
      <th>L-Glc</th>
      <th>L-GlcA</th>
      <th>L-GlcNAc</th>
      <th>L-GlcOMe</th>
      <th>L-Gro-onic</th>
      <th>L-GroHexUlo</th>
      <th>L-Gul</th>
      <th>L-Gul-onic</th>
      <th>L-GulA</th>
      <th>L-GulAN</th>
      <th>L-GulHep</th>
      <th>L-GulNAc</th>
      <th>L-GulNAcA</th>
      <th>L-GulNAcAGly</th>
      <th>L-GulNAcAN</th>
      <th>L-GulNAcANEtn</th>
      <th>L-GulNAcNAmA</th>
      <th>L-GulNAcNEtnA</th>
      <th>L-GulNAcOAc</th>
      <th>L-GulNAcOAcA</th>
      <th>L-GulNAcOAcAN</th>
      <th>L-GulNAcOEtA</th>
      <th>L-GulNAcOEtnA</th>
      <th>L-GulOAcA</th>
      <th>L-Lyx</th>
      <th>L-LyxHex</th>
      <th>L-LyxHexNMe</th>
      <th>L-LyxHexOMe</th>
      <th>L-Man</th>
      <th>L-ManOMe</th>
      <th>L-ManOctUlo-onic</th>
      <th>L-Ole</th>
      <th>L-OleOAc</th>
      <th>L-Oli</th>
      <th>L-OliOMe</th>
      <th>L-Qui</th>
      <th>L-QuiN</th>
      <th>L-QuiNAc</th>
      <th>L-QuiNAcOMe</th>
      <th>L-QuiNAcOP</th>
      <th>L-QuiOMeN</th>
      <th>L-RibHex</th>
      <th>L-Ribf</th>
      <th>L-Tal</th>
      <th>L-The</th>
      <th>L-TheOAc</th>
      <th>L-Thr</th>
      <th>L-ThrHexA4en</th>
      <th>L-ThrHexAN4en</th>
      <th>L-ThrHexOMe4en</th>
      <th>L-ThrHexOMeA4en</th>
      <th>L-ThrHexOSA4en</th>
      <th>L-Xyl</th>
      <th>L-XylHex</th>
      <th>L-XylOMe</th>
      <th>LDGalHep</th>
      <th>LDGalNonUloNAc-onic</th>
      <th>LDGlcHep</th>
      <th>LDIdoHep</th>
      <th>LDIdoHepPro</th>
      <th>LDManHep</th>
      <th>LDManHepGroN</th>
      <th>LDManHepGroPA</th>
      <th>LDManHepOAc</th>
      <th>LDManHepOCm</th>
      <th>LDManHepOEtn</th>
      <th>LDManHepOMe</th>
      <th>LDManHepOP</th>
      <th>LDManHepOPEtn</th>
      <th>LDManHepOPEtnOEtn</th>
      <th>LDManHepOPOCm</th>
      <th>LDManHepOPOMe</th>
      <th>LDManHepOPOPEtn</th>
      <th>LDManHepOPOPPEtn</th>
      <th>LDManHepOPPEtn</th>
      <th>LDManHepOPPEtnOPyrP</th>
      <th>LDManHepOPyrP</th>
      <th>LDManNonUloNAcOFoN-onic</th>
      <th>LDManNonUloOFoNN-onic</th>
      <th>LLManNonUloOFoN-onic</th>
      <th>Leg</th>
      <th>Leg5Ac7Ac</th>
      <th>LegNAc</th>
      <th>LegNAcAla</th>
      <th>LegNAcNAla</th>
      <th>LegNAcNAm</th>
      <th>LegNAcNBut</th>
      <th>LegNFo</th>
      <th>Lyx</th>
      <th>LyxHex</th>
      <th>LyxHexOMe</th>
      <th>LyxOMe</th>
      <th>LyxOctUlo-onic</th>
      <th>Lyxf</th>
      <th>Man</th>
      <th>Man-ol</th>
      <th>ManA</th>
      <th>ManCMe</th>
      <th>ManF</th>
      <th>ManGroP</th>
      <th>ManN</th>
      <th>ManNAc</th>
      <th>ManNAcA</th>
      <th>ManNAcAAla</th>
      <th>ManNAcAGro</th>
      <th>ManNAcAN</th>
      <th>ManNAcANOOrn</th>
      <th>ManNAcASer</th>
      <th>ManNAcAThr</th>
      <th>ManNAcGroA</th>
      <th>ManNAcGroP</th>
      <th>ManNAcGroPA</th>
      <th>ManNAcNAmA</th>
      <th>ManNAcNEtnA</th>
      <th>ManNAcOAc</th>
      <th>ManNAcOAcA</th>
      <th>ManNAcOLac</th>
      <th>ManNAcOMe</th>
      <th>ManNAcOMeAN</th>
      <th>ManNAcOPEtn</th>
      <th>ManNAcOPyr</th>
      <th>ManNBut</th>
      <th>ManNGroP</th>
      <th>ManNonUloNAc-onic</th>
      <th>ManOAc</th>
      <th>ManOAcA</th>
      <th>ManOAcN</th>
      <th>ManOAcOMe</th>
      <th>ManOAcOPyr</th>
      <th>ManOAep</th>
      <th>ManOBut</th>
      <th>ManOEtn</th>
      <th>ManOLac</th>
      <th>ManOMe</th>
      <th>ManOMeA</th>
      <th>ManOP</th>
      <th>ManOP-ol</th>
      <th>ManOPCho</th>
      <th>ManOPEtn</th>
      <th>ManOPOMe</th>
      <th>ManOPOPyr-ol</th>
      <th>ManOPy</th>
      <th>ManOPyr</th>
      <th>ManOS</th>
      <th>ManOctUlo</th>
      <th>ManSH</th>
      <th>Manf</th>
      <th>Mur</th>
      <th>MurNAc</th>
      <th>MurNAcAla</th>
      <th>MurNAcOP</th>
      <th>MurNAcSer</th>
      <th>Neu</th>
      <th>Neu5Ac</th>
      <th>Neu5Ac9Ac</th>
      <th>Neu5AcN</th>
      <th>Neu5AcNAc</th>
      <th>Neu5AcNMe</th>
      <th>Neu5AcOAc</th>
      <th>Neu5AcOAcOMe</th>
      <th>Neu5AcOGc</th>
      <th>Neu5AcOMe</th>
      <th>Neu5AcOS</th>
      <th>Neu5Gc</th>
      <th>Neu5GcA</th>
      <th>Neu5GcN</th>
      <th>Neu5GcOMe</th>
      <th>Neu5GcOS</th>
      <th>NeuNAc</th>
      <th>NeuOFo</th>
      <th>NeuOMe</th>
      <th>OLac</th>
      <th>Ole</th>
      <th>Oli</th>
      <th>OliN</th>
      <th>OliNAc</th>
      <th>OliOMe</th>
      <th>Par</th>
      <th>Parf</th>
      <th>PerNAc</th>
      <th>Pse</th>
      <th>Pse5Ac7Ac</th>
      <th>Pse5Ac7AcNBut</th>
      <th>Pse5Ac7AcOBut</th>
      <th>PseNAc</th>
      <th>PseNAcNAm</th>
      <th>PseNAcNBut</th>
      <th>PseNAcNFo</th>
      <th>PseNAcNGro</th>
      <th>PseNAcOAcNBut</th>
      <th>PseNAcOBut</th>
      <th>PseNButNFo</th>
      <th>PseNGcNAm</th>
      <th>PseOAc</th>
      <th>PseOAcOFo</th>
      <th>PseOFo</th>
      <th>Qui</th>
      <th>QuiN</th>
      <th>QuiNAc</th>
      <th>QuiNAc-ol</th>
      <th>QuiNAcGro</th>
      <th>QuiNAcGroP</th>
      <th>QuiNAcN</th>
      <th>QuiNAcNAlaAc</th>
      <th>QuiNAcNAm</th>
      <th>QuiNAcNAspAc</th>
      <th>QuiNAcNBut</th>
      <th>QuiNAcNButGro</th>
      <th>QuiNAcNGroA</th>
      <th>QuiNAcOAc</th>
      <th>QuiNAcOBut</th>
      <th>QuiNAcOMe</th>
      <th>QuiNAcOP</th>
      <th>QuiNAla</th>
      <th>QuiNAlaAc</th>
      <th>QuiNAlaAcGro</th>
      <th>QuiNAlaBut</th>
      <th>QuiNAlaButGro</th>
      <th>QuiNAspAc</th>
      <th>QuiNBut</th>
      <th>QuiNButAla</th>
      <th>QuiNButOMe</th>
      <th>QuiNFo</th>
      <th>QuiNGlyAc</th>
      <th>QuiNHse</th>
      <th>QuiNHseGro</th>
      <th>QuiNLac</th>
      <th>QuiNMal</th>
      <th>QuiNSerAc</th>
      <th>QuiNThrAc</th>
      <th>QuiOMe</th>
      <th>QuiOMeN</th>
      <th>QuiOS</th>
      <th>QuiOSN</th>
      <th>QuiOSNBut</th>
      <th>Rha</th>
      <th>Rha-ol</th>
      <th>RhaCMe</th>
      <th>RhaCl</th>
      <th>RhaGro</th>
      <th>RhaGroA</th>
      <th>RhaGroP</th>
      <th>RhaNAc</th>
      <th>RhaNAcNBut</th>
      <th>RhaNAcNFo</th>
      <th>RhaNAcOAc</th>
      <th>RhaNPro</th>
      <th>RhaOAc</th>
      <th>RhaOAcOLac</th>
      <th>RhaOAcOMe</th>
      <th>RhaOBut</th>
      <th>RhaOFer</th>
      <th>RhaOLac</th>
      <th>RhaOMe</th>
      <th>RhaOMeCMeNLac</th>
      <th>RhaOMeCMeOFo</th>
      <th>RhaOP</th>
      <th>RhaOPEtn</th>
      <th>RhaOPOMe</th>
      <th>RhaOProp</th>
      <th>RhaOPyr</th>
      <th>RhaOS</th>
      <th>Rhaf</th>
      <th>Rib</th>
      <th>Rib-ol</th>
      <th>RibGroP-ol</th>
      <th>RibOAc</th>
      <th>RibOAcOP-ol</th>
      <th>RibOP-ol</th>
      <th>RibOPEtn-ol</th>
      <th>RibOPGroP-ol</th>
      <th>Ribf</th>
      <th>Ribf-uronic</th>
      <th>RibfOAc</th>
      <th>Sed</th>
      <th>Sedf</th>
      <th>Sia</th>
      <th>Sor</th>
      <th>Sorf</th>
      <th>Suc</th>
      <th>Sug</th>
      <th>SugOAc</th>
      <th>Tag</th>
      <th>Tal</th>
      <th>The</th>
      <th>Thr</th>
      <th>Thre-ol</th>
      <th>Thre-onic</th>
      <th>Tyv</th>
      <th>VioNAc</th>
      <th>Xluf</th>
      <th>XlufOMe</th>
      <th>Xyl</th>
      <th>Xyl-ol</th>
      <th>Xyl-onic</th>
      <th>XylHex</th>
      <th>XylHexNAc</th>
      <th>XylHexUlo</th>
      <th>XylHexUloN</th>
      <th>XylHexUloNAc</th>
      <th>XylNAc</th>
      <th>XylNMe</th>
      <th>XylOAc</th>
      <th>XylOBz</th>
      <th>XylOMe</th>
      <th>XylOP</th>
      <th>XylOS</th>
      <th>Xylf</th>
      <th>Yer</th>
      <th>YerOAc</th>
      <th>a-Tri-ol</th>
      <th>a-Tri-onic</th>
      <th>a1-1</th>
      <th>a1-2</th>
      <th>a1-3</th>
      <th>a1-4</th>
      <th>a1-5</th>
      <th>a1-6</th>
      <th>a1-7</th>
      <th>a1-8</th>
      <th>a2-1</th>
      <th>a2-2</th>
      <th>a2-3</th>
      <th>a2-4</th>
      <th>a2-5</th>
      <th>a2-6</th>
      <th>a2-7</th>
      <th>a2-8</th>
      <th>a2-9</th>
      <th>a6-6</th>
      <th>aldehyde-2,5-Anhydro-L-Man</th>
      <th>aldehyde-2,5-Anhydro-Tal</th>
      <th>aldehyde-Gro</th>
      <th>aldehyde-Hex</th>
      <th>aldehyde-L-Gro</th>
      <th>aldehyde-L-GroN</th>
      <th>aldehyde-QuiNAc</th>
      <th>aldehyde-Rib</th>
      <th>aldehyde-a-Tri-ol</th>
      <th>aldehyde-b-Tri-ol</th>
      <th>b-Tri-N-ol</th>
      <th>b-Tri-OP-ol</th>
      <th>b-Tri-ol</th>
      <th>b-Tri-onic</th>
      <th>b1-1</th>
      <th>b1-2</th>
      <th>b1-3</th>
      <th>b1-4</th>
      <th>b1-4Glc</th>
      <th>b1-5</th>
      <th>b1-6</th>
      <th>b1-7</th>
      <th>b1-8</th>
      <th>b1-9</th>
      <th>b2-1</th>
      <th>b2-2</th>
      <th>b2-3</th>
      <th>b2-4</th>
      <th>b2-5</th>
      <th>b2-6</th>
      <th>b2-7</th>
      <th>b2-8</th>
      <th>b3-3</th>
      <th>bond</th>
      <th>cNeu5Ac</th>
      <th>monosaccharide</th>
      <th>Fuc(a1-3)GlcNAc</th>
      <th>GalNAc(a1-4)GlcNAcA</th>
      <th>GlcN(b1-7)Kdo</th>
      <th>GlcNAc(b1-4)GlcNAc</th>
      <th>GlcNAcA(a1-4)Kdo</th>
      <th>GlcOPN(b1-6)GlcOPN</th>
      <th>Kdo(a2-4)Kdo</th>
      <th>Kdo(a2-5)Kdo</th>
      <th>Kdo(a2-6)GlcOPN</th>
      <th>Man(a1-2)Man</th>
      <th>Man(a1-3)Man</th>
      <th>Man(a1-6)Man</th>
      <th>Man(b1-4)GlcNAc</th>
      <th>Xyl(b1-2)Man</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>Man(a1-3)[Man(a1-6)][Xyl(b1-2)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-3)]GlcNAc</th>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>8.0</td>
      <td>1.0</td>
      <td>4.0</td>
      <td>1.846154</td>
      <td>0.591716</td>
      <td>4.0</td>
      <td>1.0</td>
      <td>4.0</td>
      <td>4.0</td>
      <td>-3.448276e-02</td>
      <td>0.240093</td>
      <td>0.051241</td>
      <td>0.727273</td>
      <td>0.337083</td>
      <td>0.251423</td>
      <td>0.276471</td>
      <td>0.000487</td>
      <td>0.400000</td>
      <td>0.181818</td>
      <td>0.288591</td>
      <td>0.003994</td>
      <td>0.727273</td>
      <td>0.240093</td>
      <td>0.051241</td>
      <td>0.318182</td>
      <td>0.090909</td>
      <td>0.179293</td>
      <td>0.006460</td>
      <td>0.727273</td>
      <td>0.240093</td>
      <td>0.051241</td>
      <td>6.950000</td>
      <td>3.253571</td>
      <td>4.820330</td>
      <td>0.908780</td>
      <td>66.603303</td>
      <td>26.305893</td>
      <td>44.589784</td>
      <td>127.751200</td>
      <td>4.0</td>
      <td>13.0</td>
      <td>13.0</td>
      <td>0.034262</td>
      <td>-2.390521</td>
      <td>13.0</td>
      <td>12.0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>3</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
    </tr>
    <tr>
      <th>Man(a1-2)Man(a1-2)Man(a1-3)[Man(a1-3)Man(a1-6)]Man(b1-4)GlcNAc(b1-4)GlcNAc</th>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>10.0</td>
      <td>1.0</td>
      <td>3.0</td>
      <td>1.866667</td>
      <td>0.248889</td>
      <td>3.0</td>
      <td>0.0</td>
      <td>3.0</td>
      <td>3.0</td>
      <td>-2.396231e-15</td>
      <td>0.263004</td>
      <td>0.037282</td>
      <td>0.703297</td>
      <td>0.288267</td>
      <td>0.234925</td>
      <td>0.257853</td>
      <td>0.000179</td>
      <td>0.341463</td>
      <td>0.157303</td>
      <td>0.238951</td>
      <td>0.003059</td>
      <td>0.703297</td>
      <td>0.263004</td>
      <td>0.037282</td>
      <td>0.296703</td>
      <td>0.076923</td>
      <td>0.182104</td>
      <td>0.005067</td>
      <td>0.703297</td>
      <td>0.263004</td>
      <td>0.037282</td>
      <td>6.616667</td>
      <td>3.407937</td>
      <td>4.921958</td>
      <td>0.799295</td>
      <td>70.823725</td>
      <td>26.381812</td>
      <td>48.985176</td>
      <td>174.452553</td>
      <td>3.0</td>
      <td>15.0</td>
      <td>15.0</td>
      <td>0.043739</td>
      <td>-2.621893</td>
      <td>15.0</td>
      <td>14.0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>6</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
    </tr>
    <tr>
      <th>GalNAc(a1-4)GlcNAcA(a1-4)[GlcN(b1-7)]Kdo(a2-5)[Kdo(a2-4)]Kdo(a2-6)GlcOPN(b1-6)GlcOPN</th>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>10.0</td>
      <td>2.0</td>
      <td>4.0</td>
      <td>1.866667</td>
      <td>0.382222</td>
      <td>3.0</td>
      <td>0.0</td>
      <td>4.0</td>
      <td>4.0</td>
      <td>-1.449275e-02</td>
      <td>0.239560</td>
      <td>0.044684</td>
      <td>0.615385</td>
      <td>0.287575</td>
      <td>0.234359</td>
      <td>0.257668</td>
      <td>0.000274</td>
      <td>0.350000</td>
      <td>0.172840</td>
      <td>0.255611</td>
      <td>0.003247</td>
      <td>0.615385</td>
      <td>0.239560</td>
      <td>0.044684</td>
      <td>0.307692</td>
      <td>0.076923</td>
      <td>0.169545</td>
      <td>0.006240</td>
      <td>0.615385</td>
      <td>0.239560</td>
      <td>0.044684</td>
      <td>6.616667</td>
      <td>3.563492</td>
      <td>5.083122</td>
      <td>0.950051</td>
      <td>66.992537</td>
      <td>28.248894</td>
      <td>47.236515</td>
      <td>150.711681</td>
      <td>4.0</td>
      <td>15.0</td>
      <td>15.0</td>
      <td>0.025865</td>
      <td>-2.680266</td>
      <td>15.0</td>
      <td>14.0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>3</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
    </tr>
  </tbody>
</table>



```python
#identify significant binding motifs with (for instance) Z-score data
from glycowork.motif.analysis import get_pvals_motifs
glycans = ['Man(a1-3)[Man(a1-6)][Xyl(b1-2)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-3)]GlcNAc',
           'Man(a1-2)Man(a1-2)Man(a1-3)[Man(a1-3)Man(a1-6)]Man(b1-4)GlcNAc(b1-4)GlcNAc',
           'GalNAc(a1-4)GlcNAcA(a1-4)[GlcN(b1-7)]Kdo(a2-5)[Kdo(a2-4)]Kdo(a2-6)GlcOPN(b1-6)GlcOPN',
           'Man(a1-2)Man(a1-3)[Man(a1-6)]Man(b1-4)GlcNAc(b1-4)GlcNAc',
           'Glc(b1-3)Glc(b1-3)Glc']
label = [3.234, 2.423, 0.733, 3.102, 0.108]
test_df = pd.DataFrame({'glycan':glycans, 'binding':label})
out = get_pvals_motifs(test_df, glycan_col_name = 'glycan', label_col_name = 'binding').iloc[:10,:]
```




<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th></th>
      <th>motif</th>
      <th>pval</th>
      <th>corr_pval</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>4</th>
      <td>GlcNAc</td>
      <td>0.013469</td>
      <td>0.394527</td>
    </tr>
    <tr>
      <th>19</th>
      <td>b1-4</td>
      <td>0.013469</td>
      <td>0.394527</td>
    </tr>
    <tr>
      <th>8</th>
      <td>Man</td>
      <td>0.025198</td>
      <td>0.590671</td>
    </tr>
    <tr>
      <th>11</th>
      <td>a1-3</td>
      <td>0.025636</td>
      <td>0.590671</td>
    </tr>
    <tr>
      <th>13</th>
      <td>a1-6</td>
      <td>0.091752</td>
      <td>0.958241</td>
    </tr>
    <tr>
      <th>26</th>
      <td>GlcNAc(b1-4)GlcNAc</td>
      <td>0.091752</td>
      <td>0.958241</td>
    </tr>
    <tr>
      <th>33</th>
      <td>Man(a1-3)Man</td>
      <td>0.091752</td>
      <td>0.958241</td>
    </tr>
    <tr>
      <th>34</th>
      <td>Man(a1-6)Man</td>
      <td>0.091752</td>
      <td>0.958241</td>
    </tr>
    <tr>
      <th>35</th>
      <td>Man(b1-4)GlcNAc</td>
      <td>0.091752</td>
      <td>0.958241</td>
    </tr>
    <tr>
      <th>10</th>
      <td>a1-2</td>
      <td>0.130826</td>
      <td>0.980276</td>
    </tr>
  </tbody>
</table>


